using UnityEngine;
using System.IO;
using GuidewireSim;

public class CreationScript : MonoBehaviour
{
    public GameObject spherePrefab;
    public GameObject cylinderPrefab;
    private int spheresCount;
    private int cylinderCount;
    private GameObject[] spheres;
    private GameObject[] cylinders;

    private SimulationLoop simulationLoop;

    void Start()
    {
        simulationLoop = GameObject.Find("Simulation").GetComponent<SimulationLoop>();
    }

    void FixedUpdate()
    {
        SavePositionsToFile();
    }

    public void CreateGuidewire(int numberElements)
    {
        spheres = new GameObject[numberElements];
        cylinders = new GameObject[numberElements - 1];
        float rEL = simulationLoop.GetRodElementLength();

        for (int i = 0; i < numberElements; ++i)
        {
            GameObject sphere = Instantiate(spherePrefab);
            sphere.transform.position = new Vector3(0, 7, -1000 + i * rEL);
            sphere.transform.parent = this.transform;

            spheres[i] = sphere;

            if (i < numberElements - 1)
            {
                GameObject cylinder = Instantiate(cylinderPrefab);
                cylinder.layer = 6;
                cylinder.transform.parent = this.transform;

                cylinders[i] = cylinder;
            }
        }

        spheresCount = numberElements;

        simulationLoop.SetSpheres(spheres);
        simulationLoop.SetCylinders(cylinders);
    }

    public void SavePositionsToFile()
    {
    	string path = "/home/akreibich/TestRobinCode22/PositionTest22_2.txt";
    	StreamWriter writer = new StreamWriter(path, true);

    	if (spheresCount > 0)
    	{
        	Vector3 firstSpherePosition = spheres[0].transform.position;
        	writer.WriteLine("First Sphere: " + firstSpherePosition.x + "," + firstSpherePosition.y + "," + firstSpherePosition.z);

        	if (spheresCount > 1)
        	{
            	Vector3 lastSpherePosition = spheres[spheresCount - 1].transform.position;
            	writer.WriteLine("Last Sphere: " + lastSpherePosition.x + "," + lastSpherePosition.y + "," + lastSpherePosition.z);
        	}
    	}

    	writer.Close();
    }


    

    public GameObject GetLastSphere()
    {
        if (spheres != null && spheres.Length > 0)
        {
            return spheres[spheres.Length - 1];
        }
        return null;
    }

    public GameObject[] GetSpheres()
    {
        return spheres;
    }

    public GameObject[] GetCylinders()
    {
        return cylinders;
    }
}
